@@ -1,5 +1,5 @@
 shinyServer(function(input, output, session) {
-  options(shiny.maxRequestSize = 10000 * 1024^2) ## file size limit: 100MB
+  options(shiny.maxRequestSize = 10000 * 1024^2) ## file size limit
   source("server-convert.R",local = TRUE)
   source("server-evaluate.R",local = TRUE)
   source("server-monitor.R",local = TRUE)
@@ -9,7 +9,7 @@ shinyServer(function(input, output, session) {
     showModal(
       modalDialog(
         title = HTML('<p style="color:#FF6347;"><br>Attention:</br></p>'),
-        strong("MSConvert function is designed for local use only. Please read user guide for more details."),
+        strong("MSConvert function is designed for local usage only. Please read user guide for more details."),
         easyClose = TRUE
         )
       )
